@@ -25,12 +25,12 @@
 #                                                                      #
 ########################################################################
 
-from __future__ import print_function, division, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import numpy as np
 import pandas as pd
-from .util.util import hourly_index
-from .util.util import get_sun_times
+
+from .util.util import get_sun_times, hourly_index
 
 
 def disaggregate_temperature(
@@ -66,7 +66,7 @@ def disaggregate_temperature(
     ):
         raise ValueError("Invalid option")
 
-    temp_disagg = pd.Series(index=hourly_index(data_daily.index), dtype="float64")
+    temp_disagg = pd.Series(index=hourly_index(data_daily.index), dtype=float)
 
     if method in ("sine_min_max", "sine_mean", "sine"):
         # for this option assume time of minimum and maximum and fit
@@ -133,6 +133,9 @@ def disaggregate_temperature(
         locdf.mean_val_cur = data_daily.temp
         locdf.min_val_next = data_daily.tmin.shift(-1, "D")
         locdf.max_val_next = data_daily.tmax.shift(-1, "D")
+        import sys
+        print(locdf.loc[locdf.index[-1], "min_val_next"], file=sys.stderr)
+        print(locdf, file=sys.stderr)
         locdf.loc[locdf.index[-1], "min_val_next"] = locdf.min_val_cur.iloc[-1]
         locdf.loc[locdf.index[-1], "max_val_next"] = locdf.max_val_cur.iloc[-1]
         locdf.min_val_before = data_daily.tmin.shift(1, "D")
@@ -157,7 +160,7 @@ def disaggregate_temperature(
         max_val = locdf.max_val_cur.copy()
         max_val[max_val.index.hour < locdf.min_loc] = locdf.max_val_before
 
-        temp_disagg = pd.Series(index=min_val.index, dtype="float64")
+        temp_disagg = pd.Series(index=min_val.index, dtype=float)
 
         if method in ("sine_min_max", "sine"):
             delta_val = max_val - min_val
@@ -298,7 +301,7 @@ def disaggregate_temperature(
             temp_disagg.index, method="ffill", limit=23
         )
         dtr = data_daily_as_hourly.tmax - data_daily_as_hourly.tmin
-        mc = pd.Series(index=temp_disagg.index)
+        mc = pd.Series(index=temp_disagg.index, dtype=float)
         mean_course_zeromean = (
             mean_course - mean_course.mean()
         )  # shift mean course so that the daily mean is 0
