@@ -1,18 +1,14 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import sys
 import os.path
+import sys
 import warnings
 
+from mando import Program
 from mando.rst_text_formatter import RSTHelpFormatter
-
 from tstoolbox import tsutils
 
-from . import disaggregate
-from . import pet
-
-from mando import Program
+from . import disaggregate, pet
 
 warnings.filterwarnings("ignore")
 
@@ -76,14 +72,15 @@ def evaporation_cli(
     """Disaggregate daily evaporation to hourly evaporation.
 
     Parameters
-    ==========
+    ----------
     method: str
-        This is the method that will be used to disaggregate the daily
-        evaporation data.
+        This is the method that will be used to disaggregate
+        the daily evaporation data.
 
         There are two methods, a trapezoidal shape from sunrise to
         sunset called "trap" and a fixed, smooth curve starting at 0700
         (7 am) and stopping at 1900 (7 pm) called "fixed".
+    {source_units}
     {input_ts}
     {columns}
     {start_date}
@@ -94,7 +91,6 @@ def evaporation_cli(
     {skiprows}
     {index_type}
     {names}
-    {psource_units}
     {target_units}
     {print_input}
     {tablefmt}
@@ -178,7 +174,7 @@ def humidity_cli(
     +--------------+---------------------------------------------+
 
     Parameters
-    ==========
+    ----------
     method: str
 
         Available disaggregation methods for
@@ -347,7 +343,7 @@ def precipitation_cli(
     """Disaggregate daily precipitation to hourly precipitation.
 
     Parameters
-    ==========
+    ----------
     method: str
         Disaggregation methods available for precipitation.
 
@@ -445,7 +441,7 @@ def radiation_cli(
     """Disaggregate daily radiation to hourly radiation.
 
     Parameters
-    ==========
+    ----------
     method: str
         Disaggregation methods available for radiation
 
@@ -595,7 +591,7 @@ def temperature_cli(
     +---------------+----------------------------+
 
     Parameters
-    ==========
+    ----------
     method: str
 
         Disaggregation methods available for temperature.
@@ -746,7 +742,7 @@ def wind_speed_cli(
     """Disaggregate daily wind speed to hourly wind speed.
 
     Parameters
-    ==========
+    ----------
     method: str
         Disaggregation methods available for wind speed.
 
@@ -842,7 +838,7 @@ def allen_cli(
     (Tmax+Tmin)/2.
 
     Parameters
-    ==========
+    ----------
     lat: float
         The latitude of the station.  Positive specifies the Northern
         Hemisphere, and negative values represent the Southern
@@ -867,16 +863,16 @@ def allen_cli(
 
         Command line::
 
-            mettoolbox pet hargreaves 24 1 2 degF,degF < tmin_tmax_data.csv
+            mettoolbox pet allen 24 1 2 degF,degF < tmin_tmax_data.csv
 
         Python::
 
             from mettoolbox import mettoolbox as mt
-            df = mt.pet.hargreaves(24,
-                                   1,
-                                   2,
-                                   ["degF", "degF"],
-                                   input_ts="tmin_tmax_data.csv")
+            df = mt.pet.allen(24,
+                              1,
+                              2,
+                              ["degF", "degF"],
+                              input_ts="tmin_tmax_data.csv")
     {input_ts}
     {start_date}
     {end_date}
@@ -948,7 +944,7 @@ def hamon_cli(
     (Tmax+Tmin)/2.
 
     Parameters
-    ==========
+    ----------
     lat: float
         The latitude of the station.  Positive specifies the Northern
         Hemisphere, and negative values represent the Southern
@@ -977,16 +973,16 @@ def hamon_cli(
 
         Command line::
 
-            mettoolbox pet hargreaves 24 1 2 degF,degF < tmin_tmax_data.csv
+            mettoolbox pet hamon 24 1 2 degF,degF < tmin_tmax_data.csv
 
         Python::
 
             from mettoolbox import mettoolbox as mt
             df = mt.pet.hamon(24,
-                                   1,
-                                   2,
-                                   ["degF", "degF"],
-                                   input_ts="tmin_tmax_data.csv")
+                              1,
+                              2,
+                              ["degF", "degF"],
+                              input_ts="tmin_tmax_data.csv")
     {input_ts}
     {start_date}
     {end_date}
@@ -1064,7 +1060,7 @@ def hargreaves_cli(
     (Tmax+Tmin)/2.
 
     Parameters
-    ==========
+    ----------
     lat: float
         The latitude of the station.  Positive specifies the Northern
         Hemisphere, and negative values represent the Southern
@@ -1195,7 +1191,7 @@ def oudin_form_cli(
         (http://www.sciencedirect.com/science/article/pii/S0022169404004056)
 
     Parameters
-    ==========
+    ----------
     lat: float
         The latitude of the station.  Positive specifies the Northern
         Hemisphere, and negative values represent the Southern
@@ -1220,16 +1216,16 @@ def oudin_form_cli(
 
         Command line::
 
-            mettoolbox pet oudin 24 1 2 degF,degF < tmin_tmax_data.csv
+            mettoolbox pet oudin_form 24 1 2 degF,degF < tmin_tmax_data.csv
 
         Python::
 
             from mettoolbox import mettoolbox as mt
-            df = mt.pet.oudin(24,
-                              1,
-                              2,
-                              ["degF", "degF"],
-                              input_ts="tmin_tmax_data.csv")
+            df = mt.pet.oudin_form(24,
+                                   1,
+                                   2,
+                                   ["degF", "degF"],
+                                   input_ts="tmin_tmax_data.csv")
     {input_ts}
     {start_date}
     {end_date}
@@ -1276,7 +1272,7 @@ pet.oudin_form.__doc__ = oudin_form_cli.__doc__
 
 
 def main():
-    """ Main """
+    """Main"""
     if not os.path.exists("debug_mettoolbox"):
         sys.tracebacklimit = 0
     program()
