@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """
@@ -11,9 +10,10 @@ Tests for `mettoolbox` module.
 import unittest
 
 from pandas.testing import assert_frame_equal
-from mettoolbox import mettoolbox
 from tstoolbox import tstoolbox
 
+from mettoolbox import mettoolbox
+
 
 class TestMettoolbox(unittest.TestCase):
     def setUp(self):
@@ -30,7 +30,7 @@ class TestMettoolbox(unittest.TestCase):
             input_ts="tests/data_temperature_gainesville.csv",
         )
         out.index.name = "Datetime"
-        assert_frame_equal(out, self.disaggregate_temperature)
+        assert_frame_equal(out, self.disaggregate_temperature, check_dtype=False)
 
     def tearDown(self):
         pass
